@@ -7,7 +7,7 @@
 ###
 
 .DelayedMatrix_block_colCummaxs <- function(x, rows = NULL, cols = NULL,
-                                            ..., useNames = NA) {
+                                            ..., useNames = TRUE) {
   # Check input type
   stopifnot(is(x, "DelayedMatrix"))
   DelayedArray:::.get_ans_type(x, must.be.numeric = TRUE)
@@ -23,9 +23,11 @@
   if (length(val) == 0L) {
     return(numeric(ncol(x)))
   }
-  # NOTE: Return value of matrixStats::colCummaxs() has no names
-  # TODO: Obey top-level `useNames` argument.
-  unname(do.call(cbind, val))
+  val <- do.call(cbind, val)
+  if (!useNames) {
+    val <- unname(val)
+  }
+  val
 }
 
 ### ----------------------------------------------------------------------------
@@ -41,7 +43,6 @@
 #' @rdname colCummaxs
 #' @template common_params
 #' @template lowercase_x
-#' @template useNamesParameter
 #' @export
 #' @template example_dm_matrix
 #' @template example_dm_MatrixMatrix
@@ -51,7 +52,7 @@
 #' colCummaxs(dm_matrix)
 setMethod("colCummaxs", "DelayedMatrix",
           function(x, rows = NULL, cols = NULL,
-                   force_block_processing = FALSE, ..., useNames = NA) {
+                   force_block_processing = FALSE, ..., useNames = TRUE) {
             .smart_seed_dispatcher(x, generic = MatrixGenerics::colCummaxs,
                                    blockfun = .DelayedMatrix_block_colCummaxs,
                                    force_block_processing = force_block_processing,
