@@ -9,7 +9,7 @@
 .DelayedMatrix_block_colRanks <-
   function(x, rows = NULL, cols = NULL,
            ties.method = c("max", "average", "first", "last", "random", "max", "min", "dense"),
-           preserveShape = FALSE, ..., useNames = NA) {
+           preserveShape = FALSE, ..., useNames = TRUE) {
     # Check input type
     ties.method <- match.arg(ties.method)
     stopifnot(is(x, "DelayedMatrix"))
@@ -28,9 +28,11 @@
     if (length(val) == 0L) {
       return(numeric(ncol(x)))
     }
-    # NOTE: Return value of matrixStats::colRanks() has no names
-    # TODO: Obey top-level `useNames` argument.
-    unname(do.call(rbind, val))
+    val <- do.call(rbind, val)
+    if (!useNames) {
+      val <- unname(val)
+    }
+    val
   }
 
 ### ----------------------------------------------------------------------------
@@ -46,7 +48,6 @@
 #' @rdname colRanks
 #' @template common_params
 #' @template lowercase_x
-#' @template useNamesParameter
 #' @export
 #' @template example_dm_MatrixMatrix
 #' @author Peter Hickey
@@ -57,7 +58,7 @@ setMethod("colRanks", "DelayedMatrix",
           function(x, rows = NULL, cols = NULL,
                    ties.method = c("max", "average", "first", "last", "random", "max", "min", "dense"),
                    preserveShape = FALSE,
-                   force_block_processing = FALSE, ..., useNames = useNames) {
+                   force_block_processing = FALSE, ..., useNames = TRUE) {
             ties.method <- match.arg(ties.method)
             .smart_seed_dispatcher(x, generic = MatrixGenerics::colRanks,
                                    blockfun = .DelayedMatrix_block_colRanks,
@@ -65,7 +66,7 @@ setMethod("colRanks", "DelayedMatrix",
                                    rows = rows,
                                    cols = cols,
                                    ties.method = ties.method,
-                                   # preserveShape = preserveShape, # TODO: wait for a fix in SMS.
+                                   preserveShape = preserveShape,
                                    ...,
                                    useNames = useNames)
           }
