@@ -9,7 +9,7 @@
 .DelayedMatrix_block_rowQuantiles <-
   function(x, rows = NULL, cols = NULL,
            probs = seq(from = 0, to = 1, by = 0.25), na.rm = FALSE, type = 7L,
-           ..., useNames = NA, drop = TRUE) {
+           ..., useNames = TRUE, drop = TRUE) {
     # Check input type
     stopifnot(is(x, "DelayedMatrix"))
     DelayedArray:::.get_ans_type(x, must.be.numeric = FALSE)
@@ -31,9 +31,10 @@
       return(numeric(ncol(x)))
     }
 
-    # TODO: Obey top-level `useNames` argument.
     val <- do.call(rbind, val)
-    rownames(val) <- rownames(x)
+    if (useNames) {
+      rownames(val) <- rownames(x)
+    }
 
     if (drop && any(dim(val)==1L)) {
       return(drop(val))
@@ -60,7 +61,7 @@
 setMethod("rowQuantiles", "DelayedMatrix",
           function(x, rows = NULL, cols = NULL,
                    probs = seq(from = 0, to = 1, by = 0.25), na.rm = FALSE,
-                   type = 7L, force_block_processing = FALSE, ..., useNames = NA,
+                   type = 7L, force_block_processing = FALSE, ..., useNames = TRUE,
                    drop = TRUE) {
             .smart_seed_dispatcher(x, generic = MatrixGenerics::rowQuantiles,
                                    blockfun = .DelayedMatrix_block_rowQuantiles,
@@ -69,7 +70,7 @@ setMethod("rowQuantiles", "DelayedMatrix",
                                    cols = cols,
                                    probs = probs,
                                    na.rm = na.rm,
-                                   # type = type, TODO: wait for SMS to fix.
+                                   type = type,
                                    ...,
                                    useNames = useNames,
                                    drop = drop)
