@@ -8,7 +8,7 @@
 
 .DelayedMatrix_block_rowRanks <-
   function(x, rows = NULL, cols = NULL,
-           ties.method = c("max", "average", "first", "last", "random", "max", "min", "dense"), ..., useNames = NA) {
+           ties.method = c("max", "average", "first", "last", "random", "max", "min", "dense"), ..., useNames = TRUE) {
     # Check input type
     ties.method <- match.arg(ties.method)
     stopifnot(is(x, "DelayedMatrix"))
@@ -26,9 +26,11 @@
     if (length(val) == 0L) {
       return(numeric(ncol(x)))
     }
-    # NOTE: Return value of matrixStats::rowRanks() has no names
-    # TODO: Obey top-level `useNames` argument.
-    unname(do.call(rbind, val))
+    val <- do.call(rbind, val)
+    if (!useNames) {
+      val <- unname(val)
+    }
+    val
   }
 
 ### ----------------------------------------------------------------------------
@@ -49,7 +51,7 @@
 setMethod("rowRanks", "DelayedMatrix",
           function(x, rows = NULL, cols = NULL,
                    ties.method = c("max", "average", "first", "last", "random", "max", "min", "dense"),
-                   force_block_processing = FALSE, ..., useNames = NA) {
+                   force_block_processing = FALSE, ..., useNames = TRUE) {
             ties.method <- match.arg(ties.method)
             .smart_seed_dispatcher(x, generic = MatrixGenerics::rowRanks,
                                    blockfun = .DelayedMatrix_block_rowRanks,
