@@ -8,7 +8,7 @@
 
 .DelayedMatrix_block_rowWeightedMeans <- function(x, w = NULL, rows = NULL,
                                                   cols = NULL, na.rm = FALSE,
-                                                  ..., useNames = NA) {
+                                                  ..., useNames = TRUE) {
   # Check input type
   stopifnot(is(x, "DelayedMatrix"))
   DelayedArray:::.get_ans_type(x, must.be.numeric = FALSE)
@@ -37,9 +37,7 @@
   if (length(val) == 0L) {
     return(numeric(ncol(x)))
   }
-  # NOTE: Return value of matrixStats::rowWeightedMeans() has names
-  # TODO: Obey top-level `useNames` argument.
-  unlist(val, recursive = FALSE, use.names = TRUE)
+  unlist(val, recursive = FALSE, use.names = useNames)
 }
 
 ### ----------------------------------------------------------------------------
@@ -58,7 +56,7 @@
 #' rowWeightedMeans(dm_Matrix, w = 1:3)
 setMethod("rowWeightedMeans", "DelayedMatrix",
           function(x, w = NULL, rows = NULL, cols = NULL, na.rm = FALSE,
-                   force_block_processing = FALSE, ..., useNames = NA) {
+                   force_block_processing = FALSE, ..., useNames = TRUE) {
               .smart_seed_dispatcher(x, generic="rowWeightedMeans",
                                      blockfun = .DelayedMatrix_block_rowWeightedMeans,
                                      force_block_processing = force_block_processing,
