@@ -25,6 +25,15 @@ message2 <- function(msg, verbose = FALSE) {
   }
 }
 
+# Check, normalize, and subset 'center' argument.
+# Supplied 'center' must be either NULL or a numeric vector of length 'n'
+# or 1.
+normarg_center_and_subset <- function(center, n, what, idx=NULL)
+{
+    center <- MatrixGenerics::normarg_center(center, n, what)
+    if (is.null(idx)) center else center[idx]  # 'idx' is trusted
+}
+
 # TODO: Figure out a minimal definition of a "simple seed"; Hervé defines a
 #       "seed contract" as dim(), dimnames(), and extract_array(); see
 #       DelayedArray vignette
@@ -334,10 +343,10 @@ rowblock_APPLY <- function(x, FUN, ...) {
     blockApply(x, FUN=.sparse_handler, FUN, ..., as.sparse=NA, grid=rowAutoGrid(x))
 }
 
-#' @importClassesFrom DelayedArray SparseArraySeed
+#' @importClassesFrom SparseArray SparseArray
 #' @importClassesFrom Matrix sparseMatrix
 .sparse_handler <- function(x, FUN, ...) {
-    if (is(x, "SparseArraySeed")) {
+    if (is(x, "SparseArray")) {
         x <- as(x, "sparseMatrix")
     }
     FUN(x, ...)
